import click

from gcs_cli.helpers import requires_login
from gcs_cli.parsing import globus_command
from gcs_cli.prettyprint import FORMAT_TEXT_RECORD, formatted_print
from gcs_cli.sdk_client.data import CollectionDocument
from gcs_cli.services.gcs import get_client


@globus_command("create-guest", short_help="Create a new Guest Collection", hidden=True)
@click.argument("MAPPED_COLLECTION_ID")
@click.argument("CREDENTIAL_ID")
@click.argument("BASE_PATH")
@click.argument("DISPLAY_NAME")
@click.option(
    "--public/--private",
    "public",
    help="Set the collection to be private or public (defaults to public)",
    default=True,
)
@requires_login
def collection_create_guest(
    mapped_collection_id, credential_id, base_path, display_name, public
):
    """
    Create a new Guest Collection, rooted on some given path within an
    existing Mapped Collection.

    The MAPPED_COLLECTION_ID is the Mapped Collection which will host this
    Guest Collection.

    [WARNING]: For Internal Use Only
    This command may change in future versions without notice.
    """
    collection_doc = CollectionDocument(
        collection_type="guest",
        mapped_collection_id=mapped_collection_id,
        user_credential_id=credential_id,
        collection_base_path=base_path,
        display_name=display_name,
        public=public,
    )
    client = get_client()
    res = client.create_collection(collection_doc)

    # output
    formatted_print(
        res, fields=[("Collection ID", "id")], text_format=FORMAT_TEXT_RECORD
    )
