import click

from gcs_cli.helpers import default_principal_resolver, requires_login
from gcs_cli.parsing import collection_id_arg, globus_command
from gcs_cli.prettyprint import FORMAT_TEXT_TABLE, formatted_print
from gcs_cli.services.gcs import get_client

FIELDS = [
    ("Role ID", "id"),
    ("Collection ID", "collection"),
    ("Role", "role"),
    ("Principal", default_principal_resolver.field),
]


@globus_command("list", short_help="List Roles on a Collection.")
@collection_id_arg
@click.option("--my-roles", is_flag=True, help="Only list roles which apply to you")
@requires_login
def role_list(collection_id, my_roles=False):
    """
    List Roles on a Collection.
    """
    if not my_roles:
        include = "all_roles"
    else:
        include = None

    client = get_client()
    res = client.paginated.get_role_list(collection_id=collection_id, include=include)

    formatted_print(
        res,
        text_format=FORMAT_TEXT_TABLE,
        fields=FIELDS,
        page_callback=default_principal_resolver.page_callback,
    )
