import click

from gcs_cli.helpers import create_principal, requires_login
from gcs_cli.parsing import globus_command, role_create_params
from gcs_cli.prettyprint import FORMAT_TEXT_RECORD, formatted_print
from gcs_cli.sdk_client.data import RoleDocument
from gcs_cli.services.gcs import get_client


@globus_command("create", short_help="Create a new Endpoint Role")
@role_create_params(endpoint=True)
@requires_login
def role_create(role, principal_type, principal_name_or_id, provision, **kwargs):
    """
    Create a new Endpoint Role.
    """
    principal = create_principal(
        principal_type, principal_name_or_id, provision=provision
    )
    if not principal:
        click.echo(
            "Unable to resolve principal {}. "
            "Use --provision to auto-provision an identity.".format(
                principal_name_or_id
            ),
            err=True,
        )
        click.get_current_context().exit(1)

    role_doc = RoleDocument(role=role, principal=principal)

    client = get_client()
    res = client.create_role(role_doc)

    # output
    formatted_print(res, fields=[("Role ID", "id")], text_format=FORMAT_TEXT_RECORD)
