import uuid

import click

from gcs_cli.helpers import record_print_result_message, requires_login
from gcs_cli.parsing import UUIDorUsername, globus_command
from gcs_cli.services.auth import get_client as get_auth_client
from gcs_cli.services.gcs import get_client


@globus_command("set-owner", short_help="Set an endpoint owner")
@click.argument("OWNER", type=UUIDorUsername())
@requires_login
def endpoint_set_owner(owner):
    """
    Update the owner on the endpoint to which you are currently logged in

    This command may only be performed by the current endpoint owner, but allows
    changing ownership to another identity.
    """
    client = get_client()
    owner_id = None
    if owner and not isinstance(owner, str):
        owner = str(owner)

    try:
        uuid.UUID(owner)
        owner_id = owner
    except ValueError:
        auth_client = get_auth_client()
        res = auth_client.get_identities(usernames=owner)["identities"]

        if not res:
            res = []
        for identity in res:
            if identity["username"] == owner:
                owner_id = identity["id"]
                break
        if not owner_id:
            click.echo("No such identity {}".format(owner), err=True)
            click.get_current_context().exit(1)

    doc = {"DATA_TYPE": "endpoint_owner#1.0.0", "identity_id": owner_id}

    res = client.put_endpoint_owner(data=doc)
    record_print_result_message(res)
