import uuid

from gcs_cli.helpers import requires_login
from gcs_cli.parsing import EXPLICIT_NULL, endpoint_update_params, globus_command
from gcs_cli.prettyprint import FORMAT_TEXT_RECORD, formatted_print
from gcs_cli.services.gcs import get_client


@globus_command("update", short_help="Update an endpoint definition")
@endpoint_update_params
@requires_login
def endpoint_update(**kwargs):
    """
    Update the endpoint which the GCS CLI is logged into
    """
    client = get_client()

    doc = {"DATA_TYPE": "endpoint#1.0.0"}
    for k, v in kwargs.items():
        if v is None:
            continue
        if v == EXPLICIT_NULL:
            doc[k] = None
        elif isinstance(v, uuid.UUID):
            doc[k] = str(v)
        else:
            doc[k] = v

    res = client.update_endpoint(data=doc)

    formatted_print(res, fields=[("code", "code")], text_format=FORMAT_TEXT_RECORD)
