from gcs_cli.helpers import requires_login
from gcs_cli.parsing import globus_command
from gcs_cli.prettyprint import FORMAT_TEXT_TABLE, formatted_print
from gcs_cli.services.gcs import get_client


def format_ip_addresses(node):
    first = node["ip_addresses"][0]
    if len(node["ip_addresses"]) == 1:
        return first
    else:
        return first + ", ..."


@globus_command("list", short_help="List all Nodes on the Endpoint")
@requires_login
def node_list():
    """
    Show all Nodes on the current Endpoint

    If a node has multiple IPs, only one will be shown in text output. Use JSON output
    or `node show` to see all IPs.
    """
    client = get_client()
    res = client.paginated.get_node_list()
    formatted_print(
        res,
        text_format=FORMAT_TEXT_TABLE,
        fields=[
            ("ID", "id"),
            ("IP Addresses", format_ip_addresses),
            ("Status", "status"),
        ],
    )
