from gcs_cli.commands.storage_gateway._common import make_create_command
from gcs_cli.parsing import (
    globus_command,
    posix_staging_options,
    storage_gateway_create_and_update_params,
)
from gcs_cli.sdk_client.data import POSIXStagingStoragePolicies, StorageGatewayDocument
from gcs_cli.services.gcs import POSIX_STAGING_CONNECTOR_ID


@globus_command(
    "posix-staging", short_help="Create a new POSIX Staging storage gateway"
)
@storage_gateway_create_and_update_params(create=True)
@posix_staging_options(create=True)
@make_create_command
def posix_staging_create(
    *, posix_group_allow, posix_group_deny, stage_app, environment, **kwargs
):
    """
    Create a new storage gateway. Requires a display name and a connector.
    Additional connector specific options may be required as well.
    """
    policies = POSIXStagingStoragePolicies(
        groups_allow=posix_group_allow,
        groups_deny=posix_group_deny,
        stage_app=stage_app,
        environment=environment,
    )
    return StorageGatewayDocument(
        connector_id=POSIX_STAGING_CONNECTOR_ID, policies=policies, **kwargs
    )
