from gcs_cli.commands.storage_gateway._common import make_update_command
from gcs_cli.parsing import (
    globus_command,
    google_cloud_storage_options,
    storage_gateway_create_and_update_params,
    storage_gateway_id_arg,
)
from gcs_cli.sdk_client.data import GoogleCloudStoragePolicies, StorageGatewayDocument
from gcs_cli.services.gcs import GOOGLE_CLOUD_STORAGE_CONNECTOR_ID


@globus_command(
    "google-cloud-storage", short_help="Update a Google Cloud Storage Storage Gateway"
)
@storage_gateway_id_arg
@storage_gateway_create_and_update_params(create=False)
@google_cloud_storage_options
@make_update_command
def google_cloud_storage_update(
    storage_gateway_id,
    *,
    google_client_id,
    google_client_secret,
    google_service_account_key,
    bucket,
    google_cloud_storage_project,
    **kwargs
):
    """
    Update an existing Google Cloud Storage Storage Gateway.
    Any options given will replace existing values in the storage gateway's definition.
    Any options not given will retain their existing values.
    """
    policies = None
    if any(
        x is not None
        for x in (
            google_client_id,
            google_client_secret,
            google_service_account_key,
            bucket,
            google_cloud_storage_project,
        )
    ):
        policies = GoogleCloudStoragePolicies(
            client_id=google_client_id,
            secret=google_client_secret,
            service_account_key=google_service_account_key,
            buckets=bucket,
            projects=google_cloud_storage_project,
        )

    return (
        storage_gateway_id,
        StorageGatewayDocument(
            connector_id=GOOGLE_CLOUD_STORAGE_CONNECTOR_ID, policies=policies, **kwargs
        ),
    )
