from gcs_cli.commands.storage_gateway._common import make_update_command
from gcs_cli.parsing import (
    globus_command,
    irods_options,
    storage_gateway_create_and_update_params,
    storage_gateway_id_arg,
)
from gcs_cli.sdk_client.data import IrodsStoragePolicies, StorageGatewayDocument
from gcs_cli.services.gcs import IRODS_CONNECTOR_ID


@globus_command("irods", short_help="Update a iRODS Storage Gateway")
@storage_gateway_id_arg
@storage_gateway_create_and_update_params(create=False)
@irods_options
@make_update_command
def irods_update(
    storage_gateway_id, *, irods_environment_file, irods_authentication_file, **kwargs
):
    """
    Update an existing iRODS Storage Gateway.
    Any options given will replace existing values in the storage gateway's definition.
    Any options not given will retain their existing values.
    """
    policies = None
    if irods_environment_file is not None or irods_authentication_file is not None:
        policies = IrodsStoragePolicies(
            irods_authentication_file=irods_authentication_file,
            irods_environment_file=irods_environment_file,
        )

    return (
        storage_gateway_id,
        StorageGatewayDocument(
            connector_id=IRODS_CONNECTOR_ID, policies=policies, **kwargs
        ),
    )
