from gcs_cli.commands.storage_gateway._common import make_update_command
from gcs_cli.parsing import (
    globus_command,
    posix_staging_options,
    storage_gateway_create_and_update_params,
    storage_gateway_id_arg,
)
from gcs_cli.sdk_client.data import POSIXStagingStoragePolicies, StorageGatewayDocument
from gcs_cli.services.gcs import POSIX_STAGING_CONNECTOR_ID


@globus_command("posix-staging", short_help="Update a POSIX Staging Storage Gateway")
@storage_gateway_id_arg
@storage_gateway_create_and_update_params(create=False)
@posix_staging_options(create=False)
@make_update_command
def posix_staging_update(
    storage_gateway_id,
    *,
    posix_group_allow,
    posix_group_deny,
    stage_app,
    environment,
    **kwargs
):
    """
    Update an existing POSIX Staging Storage Gateway.
    Any options given will replace existing values in the storage gateway's definition.
    Any options not given will retain their existing values.
    """
    policies = None
    if (
        posix_group_allow is not None
        or posix_group_deny is not None
        or stage_app is not None
        or environment is not None
    ):
        policies = POSIXStagingStoragePolicies(
            groups_allow=posix_group_allow, groups_deny=posix_group_deny
        )
        if stage_app:
            policies["stage_app"] = stage_app
        if environment is not None:
            policies["environment"] = environment if environment else []

    return (
        storage_gateway_id,
        StorageGatewayDocument(
            connector_id=POSIX_STAGING_CONNECTOR_ID, policies=policies, **kwargs
        ),
    )
