import json
import os
import pathlib
from zipfile import BadZipFile, ZipFile

import click

from ..version import __version__


@click.command("list")
@click.version_option(version=__version__)
def snapshot_list() -> None:
    snapshot_dir = pathlib.Path("migration_snapshots")
    if not snapshot_dir.exists():
        raise click.ClickException("No snapshots exist")

    snapshots = {}
    for fn in os.listdir(snapshot_dir):
        try:
            idx = int(fn)

            with ZipFile(snapshot_dir / fn, mode="r") as z:
                with z.open("metadata.json", "r") as f:
                    snapshots[idx] = json.load(f)
        except (ValueError, BadZipFile):
            pass

    fields = ["ID", "Timestamp", "Description"]
    field_lengths = [len(f) for f in fields]

    field_lengths[1] = 19

    for snapshot_id, metadata in snapshots.items():
        if len(f"{snapshot_id}") > field_lengths[0]:
            field_lengths[0] = len(f"{snapshot_id}")
        if len(metadata.get("description", "")) > field_lengths[2]:
            field_lengths[2] = len(metadata["description"])

    fmt = " | ".join(f"{{:{fl}}}" for fl in field_lengths)
    click.echo(fmt.format(*fields))
    click.echo(fmt.format(*["-" * fl for fl in field_lengths]))

    for snapshot_id in sorted(snapshots.keys()):
        metadata = snapshots[snapshot_id]
        click.echo(
            fmt.format(
                snapshot_id,
                metadata.get("timestamp", ""),
                metadata.get("description", ""),
            )
        )
