from globus.manager.constants import ConfigurationObjectTag
from .user_credential import UserCredential


class IrodsUserCredential(UserCredential):
    POLICY_DATA_TYPE = "irods_user_credential_policies#1.0.0"
    CONNECTOR_ID = "e47b6920-ff57-11ea-8aaa-000c297ab3c2"

    __mapper_args__ = {
        "polymorphic_identity": (
            ConfigurationObjectTag.USER_CREDENTIAL.name + CONNECTOR_ID
        )
    }

    def __init__(self, appsync_data=None, doc=None, storage_gateway=None):
        if doc:
            username = doc["username"]
            policy = doc.get("policy")
            if not policy:
                policy = {"DATA_TYPE": self.POLICY_DATA_TYPE}
            doc = {
                **doc,
                **{
                    "display_name": username,
                    "invalid": False,
                    "deleted": False,
                    "provisioned": True,
                    "policy": policy,
                },
            }

        super().__init__(
            appsync_data=appsync_data, doc=doc, storage_gateway=storage_gateway
        )

    def put(self, **doc):
        display_name = self.storage_gateway.get_user_display_name(self.username)
        super().put(**{**doc, **{"display_name": display_name}})

    def patch(self, **doc):
        doc.pop("display_name", None)
        super().patch(**doc)

    @property
    def connector_id(self):
        return self.CONNECTOR_ID

    @connector_id.setter
    def connector_id(self, value):
        pass

    def __repr__(self):
        return "<IrodsUserCredential {}>".format(self.id)
