from .data_type import DataTypeSchema
from .schema_version_checker import verify_schema_version
import marshmallow as ma


class EndpointOwnerSchema(ma.Schema):
    """
    Schema for processing the endpoint_owner#1.0.0 data type
    """

    _DATA_TYPE = "endpoint_owner#1.0.0"

    DATA_TYPE = ma.fields.String(
        required=True,
        allow_none=False,
        default=_DATA_TYPE,
        doc="Type of this document",
    )

    identity_id = ma.fields.UUID(
        required=True, doc="Auth identity ID of the endpoint owner"
    )

    @ma.validates("DATA_TYPE")
    def validate_data_type(self, data, **kwargs):
        verify_schema_version(data, self._DATA_TYPE)


endpoint_owner_schema = EndpointOwnerSchema()

DataTypeSchema.register_schema(endpoint_owner_schema)
