from typing import List, Optional
import uuid

import marshmallow as ma
from mypy_extensions import TypedDict
from typing_extensions import Literal

from .data_type import DataTypeSchema
from .path_restrictions import path_restrictions_schema, PathRestrictionsDict


SharingPolicyDumpDict = TypedDict(
    "SharingPolicyDumpDict",
    {
        "DATA_TYPE": Literal["sharing_policy#1.0.0"],
        "id": str,
        "collection_id": str,
        "sharing_restrict_paths": PathRestrictionsDict,
        "users": Optional[List[str]],
    },
    total=False,
)


SharingPolicyLoadDict = TypedDict(
    "SharingPolicyLoadDict",
    {
        "DATA_TYPE": Literal["sharing_policy#1.0.0"],
        "id": uuid.UUID,
        "collection_id": uuid.UUID,
        "sharing_restrict_paths": PathRestrictionsDict,
        "users": Optional[List[str]],
    },
    total=False,
)


class SharingPolicySchema(ma.Schema):
    _DATA_TYPE = "sharing_policy#1.0.0"
    DATA_TYPE = ma.fields.String(
        required=True,
        allow_none=False,
        default=_DATA_TYPE,
        validate=[ma.validate.Equal(_DATA_TYPE)],
    )
    id = ma.fields.UUID()
    collection_id = ma.fields.UUID(required=True)
    sharing_restrict_paths = ma.fields.Nested(path_restrictions_schema, required=True)
    users = ma.fields.List(ma.fields.String)

    def load(self, *args, **kwargs) -> SharingPolicyLoadDict:
        return super().load(*args, **kwargs)


sharing_policy_schema = SharingPolicySchema()
DataTypeSchema.register_schema(sharing_policy_schema)
