from typing import List

import marshmallow as ma

from ..api.collection import CollectionSchema
from ..api.data_type import DataTypeSchema
from ..api.storage_gateway import StorageGatewaySchema
from ..api.user_credential import UserCredentialSchema


BLACKPEARL_CONNECTOR_ID = "7e3f3f5e-350c-4717-891a-2f451c24b0d4"


class BlackPearlStoragePoliciesSchema(ma.Schema):
    _DATA_TYPE = "blackpearl_storage_policies#1.0.0"
    DATA_TYPE = ma.fields.Str(
        required=True,
        allow_none=False,
        default=_DATA_TYPE,
        validate=[ma.validate.Equal(_DATA_TYPE)],
    )
    s3_endpoint = ma.fields.Url(schemes=["http", "https"])
    bp_access_id_file = ma.fields.Str()
    private = ["bp_access_id_file"]
    connector_id = BLACKPEARL_CONNECTOR_ID


class BlackPearlCollectionPoliciesSchema(ma.Schema):
    _DATA_TYPE = "blackpearl_collection_policies#1.0.0"
    DATA_TYPE = ma.fields.String(
        required=True,
        allow_none=False,
        default=_DATA_TYPE,
        validate=[ma.validate.Equal(_DATA_TYPE)],
    )
    private = []  # type: List[str]
    connector_id = BLACKPEARL_CONNECTOR_ID


class BlackPearlUserCredentialPoliciesSchema(ma.Schema):
    _DATA_TYPE = "blackpearl_user_credential_policies#1.0.0"
    DATA_TYPE = ma.fields.String(
        required=True,
        allow_none=False,
        default=_DATA_TYPE,
        validate=[ma.validate.Equal(_DATA_TYPE)],
    )
    access_id = ma.fields.String(dump_only=True)
    secret_key = ma.fields.String(dump_only=True)
    private = ["secret_key"]  # type: List[str]
    connector_id = BLACKPEARL_CONNECTOR_ID


blackpearl_user_credential_policies_private_schema = (
    BlackPearlUserCredentialPoliciesSchema()
)
blackpearl_user_credential_policies_schema = BlackPearlUserCredentialPoliciesSchema(
    load_only=BlackPearlUserCredentialPoliciesSchema.private
)
blackpearl_storage_policies_include_private_schema = BlackPearlStoragePoliciesSchema()
blackpearl_storage_policies_schema = BlackPearlStoragePoliciesSchema(
    load_only=BlackPearlStoragePoliciesSchema.private
)
blackpearl_storage_policies_private_schema = BlackPearlStoragePoliciesSchema()
blackpearl_collection_policies_schema = BlackPearlCollectionPoliciesSchema()
blackpearl_collection_policies_private_schema = BlackPearlCollectionPoliciesSchema(
    load_only=BlackPearlCollectionPoliciesSchema.private
)

DataTypeSchema.register_schema(blackpearl_storage_policies_schema)
DataTypeSchema.register_schema(blackpearl_user_credential_policies_schema)
DataTypeSchema.register_schema(blackpearl_collection_policies_schema)

StorageGatewaySchema.register_schema(
    public=blackpearl_storage_policies_schema,
    private=blackpearl_storage_policies_include_private_schema,
)

UserCredentialSchema.register_schema(
    public=blackpearl_user_credential_policies_schema,
    private=blackpearl_user_credential_policies_private_schema,
)

CollectionSchema.register_schema(
    public=blackpearl_collection_policies_schema,
    private=blackpearl_collection_policies_schema,
)
