"""
globus-connect-server node set-configuration
"""
import click

from globus.manager.api.app import make_app
from globus.manager.api.models import (
    db,
    Configuration,
)
from gcs_cli.parsing.command_decorator import globus_command


@globus_command(
    "set-configuration",
    short_help="Update node configuration",
    help="Update node configuration",
    hidden=True,
    disable_options=["format", "explicit_host"],
)
@click.argument("NAME")
@click.argument("VALUE", required=False)
@click.pass_context
def node_set_configuration(ctx, name, value=None):
    app = make_app(app_config="globus.manager.api.config.production")
    db.init_app(app)

    if not value:
        value = click.prompt("New value for {}".format(name)).strip()

    with app.app_context():
        app.logger.info("node_set_configuration: start")
        entry = Configuration.query.filter(Configuration.name == name).one_or_none()

        if not entry:
            entry = Configuration(name, value)
        else:
            entry.value = value

        db.session.add(entry)
        db.session.commit()
