import rsa
from os import path
import logging

log = logging.getLogger(__name__)


def create_keys(key_folder: str):
    """
    Create the key files if they do not exist already.
    Using RSA module, which is imported by python-jose.
    """
    try:
        keyfile = path.join(key_folder, 'key.pem')
        if path.exists(keyfile):
            return
        (pubkey, privkey) = rsa.newkeys(1024)
        with open(keyfile, 'wb') as f:
            f.write(privkey.save_pkcs1('PEM'))
        with open("{}.pub".format(keyfile), 'wb') as f:
            f.write(pubkey.save_pkcs1('PEM'))
    except Exception as e:
        err = "Unable to load or generate key files - {}".format(str(e))
        log.error(err)
        raise Exception(err)
